California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
OLLER, THOMAS PETERSEN, JON ROMERO, THOMAS "TOM"
| STATE SENATE 03
BURTON, JOHN L. FAULKNER, TERRENCE JOKI, CELESTE JOY BLAU
STATE SENATE 05
BROW, CAROLE MACHADO, MICHAEL J. NAKANISHI, ALAN S. NICOLAS, WILLIAM S.
| STATE SENATE 07
BILLINGS, MARK RAINEY, DICK TORLAKSON, TOM
STATE SENATE 09
EYER, JAMES M. MARSHALL, LINDA J. PERATA, DON
| STATE SENATE 11
HICKEY, JOHN J. HOM, GLORIA SHER, BYRON
STATE SENATE 13
LONGWELL, JOHN VASCONCELLOS, JOHN WEBSTER, JOHN H.
| STATE SENATE 15
CHAVEZ, ANSELMO A. MC PHERSON, BRUCE ROSENKRANZ, DAVID SACHTJEN, GORDON D.
STATE SENATE 17
GIBSON, JOHN R. KNIGHT, WILLIAM J. "PETE" LOTT, RICHARD WALLACK, DOUGLAS R.
| STATE SENATE 19
GONZALEZ, DANIEL R. MC CLINTOCK, THOMAS
STATE SENATE 21
NEW, BOB SCOTT, JACK ZEE, PAUL
| STATE SENATE 23
BLACK, CHARLES T. KUEHL, SHEILA J. REGO, DANIEL B.
STATE SENATE 25
MC CLAIN, CLIFF VINCENT, EDWARD
| STATE SENATE 27
KARNETTE, BETTY LYON, MARILYN
STATE SENATE 29
FAEGRE, LELAND THOMAS MARGETT, ROBERT MELENDEZ, RICHARD
| STATE SENATE 31
BRULTE, JAMES L. RAYBURN, MIKE WARD, FRITZ R.
STATE SENATE 33
ACKERMAN, RICHARD CHACON, MICHAEL ROBERTS, JACK VERKAMP, WM. (BILL)
| STATE SENATE 35
JOHNSON, ROSS KATZ, CINDY RAY, STEVE STUDIER, PAUL L.
STATE SENATE 37
BATTIN JR., JAMES F. SANDERS, SEDALIA L. TELLO, DONNA
| STATE SENATE 39
ALPERT, DEDE KNOLES, STUART NICHOLS, RUSTY STIRLING, LARRY
ASSEMBLY DISTRICTS
ASSEMBLY 01
GILLEO, JOSHUA LAMPSON, MIKE STROM-MARTIN, VIRGINIA
| ASSEMBLY 02
BRET, PETE ANTHONY DICKERSON, RICHARD "DICK" PARKS, VIRGIL THIESSEN, PATRICE
ASSEMBLY 03
AANESTAD, SAMUEL M. THOMASON, WILLIAM L. WIRTSCHAFTER, BENJAMIN
| ASSEMBLY 04
LESLIE, R. TIM MACOLA, STEPHEN A.
ASSEMBLY 05
COX, DAVE FRAZIER, GENE
| ASSEMBLY 06
NATION, JOE OLMSTEAD, RICHARD SULLIVAN, ED
ASSEMBLY 07
RIVERA, PEDRO J. SCHOEFFLER, WILLIAM WIGGINS, PATRICIA ANN
| ASSEMBLY 08
MUNN, JOHN R. THOMSON, HELEN M. (501WITHDRAWN) WILSON II, ROBERT W.
ASSEMBLY 09
BERGERON, JAN L. HARGRAVE, CHARLES SAUNDERS, BRUCE B. STEINBERG, DARRELL
| ASSEMBLY 10
GRAVERT, DEBRA KOHLHEPP, TOM PESCETTI, ANTHONY
ASSEMBLY 11
CANCIAMILLA, JOSEPH DIAZ, JIM MANSKE, FRANK J. ROSAS, LOU
| ASSEMBLY 12
EPSTEIN, HOWARD SHELLEY, KEVIN
ASSEMBLY 13
LANE, BOB MIGDEN, CAROLE STARCHILD
| ASSEMBLY 14
ARONER, DION LOUISE BURTON, DANIEL C. UDINSKY, JERALD
ASSEMBLY 15
LEACH, LYNNE C. ROLEN, GREG
| ASSEMBLY 16
ARMSTRONG, RICHARD E. BOCK, AUDIE E. CHAN, WILMA MC CORMICK, TIMOTHY B.
ASSEMBLY 17
AGHAZARIAN, GREG BUSCH, ROY W. MATTHEWS, BARBARA
| ASSEMBLY 18
CORBETT, ELLEN MAHMOOD, SYED
ASSEMBLY 19
KASSEL, STEVEN H. LUNDRY, STEVE C. PAPAN, LOU SIX, PAUL J.
| ASSEMBLY 20
DUTRA, JOHN A. KING, LOWELL WERLWAS, MARK
ASSEMBLY 21
PURCELL, GLORIA SIMITIAN, S. JOSEPH WILDER, DEBORAH
| ASSEMBLY 22
ALQUIST, ELAINE KAWCZYNSKI, STAN
ASSEMBLY 23
ALBRECHT, DANA W. ASKELAND, TOM DIAZ, MANNY
| ASSEMBLY 24
COHN, REBECCA JACKSON, SUE STRONG, RAY
ASSEMBLY 25
COGDILL, DAVID E. RICO, STEPHEN F. ZWICKEL, JONATHAN IRA
| ASSEMBLY 26
CARDOZA, DENNIS SANCHEZ, MARSHALL
ASSEMBLY 27
BONINO, DAVID R. CARTER, CHARLES "CHUCK" DE JOLY, MADELINE KEELEY, FRED
| ASSEMBLY 28
DENHAM, JEFF SALINAS, SIMON VER, ROGER VOGEL, JOHN
ASSEMBLY 29
BRIGGS, MIKE DRIOANE, RON REID, LITA
| ASSEMBLY 30
FLOREZ, DEAN KAY, KEN
ASSEMBLY 31
CABRAL, RICHARD GUERRA REYES, SARAH
| ASSEMBLY 32
ASHBURN, ROY GURROLA, VIRGINIA PINKERTON, RIC
ASSEMBLY 33
HOULGATE, LAURENCE MALDONADO, ABEL
| ASSEMBLY 34
CONAWAY, ROBERT "BOB" WYMAN, PHILLIP D.
ASSEMBLY 35
DAHL, ERIC JACKSON, HANNAH-BETH SULLIVAN, ROBIN S.
| ASSEMBLY 36
BASHEM, GREGORY JAMES CALDERON, PAULA L. RUNNER, GEORGE C.
ASSEMBLY 37
MC GRATH, ROZ MICHLIN, WILLARD D. STRICKLAND, TONY
| ASSEMBLY 38
BARON, PHILIP LAURITZEN, JON M. RICHMAN, KEITH STUART
ASSEMBLY 39
CARDENAS, TONY MAIRA, CHRISTOPHER "KIT" VALDEZ, ENRIQUE (HENRY)
| ASSEMBLY 40
HAMMANS, KYLE HERTZBERG, ROBERT ROSS, KELLEY L.
ASSEMBLY 41
GOLDMAN, COLIN S. PAVLEY, FRAN SHAPIRO, JAYNE M.
| ASSEMBLY 42
ADAM, IVKA AMIR, SARA KORETZ, PAUL SELZER, MARK ALLEN TAYLOR, DOUGLAS CLEON
ASSEMBLY 43
FROMMER, DARIO MISSAKIAN, CRAIG HARRY
| ASSEMBLY 44
DOUGLAS, JERRY LIU, CAROL MC MILLAN, SUSAN CARPENTER
ASSEMBLY 45
GOLDBERG, JACKIE
| ASSEMBLY 46
BROWN, MATT CEDILLO, GILBERT
ASSEMBLY 47
LEONARD, JONATHAN PACER, SCOTT WESSON, JR., HERMAN J.
| ASSEMBLY 48
WOODS, ERNEST L. WRIGHT, RODERICK "ROD"
ASSEMBLY 49
ROMERO, GLORIA
| ASSEMBLY 50
FIREBAUGH, MARCO ANTONIO MILLER, GLADYS O.
ASSEMBLY 51
HAWKINS, ANTOINE HORTON, JEROME E.
| ASSEMBLY 52
ILES, MARK ANTHONY WASHINGTON, CARL
ASSEMBLY 53
FELANDO, GERALD HOWITT, PHIL NAKANO, GEORGE
| ASSEMBLY 54
LOWENTHAL, ALAN OGDEN, DALE F. SVORINICH, RUDOLPH
ASSEMBLY 55
LANKSTER, SAUL E. OROPEZA, JENNY WILSON, GUY
| ASSEMBLY 56
HAVICE, SALLY HU, GRACE
ASSEMBLY 57
CHAVEZ, EDWARD "ED" VENTUROSO, KATHERINE LICARI
| ASSEMBLY 58
BURROLA, ALEX A. CALDERON, THOMAS M.
ASSEMBLY 59
ALLISON, LOUISE M. HALL, MELINE DOLORES MOUNTJOY, DENNIS WHITE, GEORGE
| ASSEMBLY 60
DUHAMEL, JEFF A. PACHECO, ROBERT "BOB" YOUNG, SCOTT E.
ASSEMBLY 61
KOCOT, DAVID MC LEOD, GLORIA NEGRETE YATES, DENNIS R.
| ASSEMBLY 62
LONGVILLE, JOHN MARTINEZ, MARY LOU MATUS, HENRY JOHN
ASSEMBLY 63
LEONARD, BILL MOHLER, ETHEL M. STOTZ, SCOTT T.
| ASSEMBLY 64
MEDINA, JOSE J. PACHECO, RODRIC A. TURNER, PHIL WALLACK, ANNIE
ASSEMBLY 65
FLICKINGER, BONNIE LEJA, JAN QUINTO, RAY R. RENTERIA, JOSEPH RAY
| ASSEMBLY 66
CANFIELD, BOB HOLLINGSWORTH, DENNIS REUTTER, CHUCK
ASSEMBLY 67
BROWNE, AUTUMN HILBERT, ANDREW MARTIN
| ASSEMBLY 68
LAINE, SHEILA JAMES MADDOX, KENNETH NEWHOUSE, RICHARD G. SNOOK, AL
ASSEMBLY 69
CORREA, LOU LOPEZ, LOU PHAM, BRIAN TUAN
| ASSEMBLY 70
CAMPBELL, JOHN B.T. KATZ, BARRY L. MC KEON, MERRITT LORI MILLS, RAYMOND O. VONDRUSKA, ROBERT ANTHONY
ASSEMBLY 71
BRYANT, BRENDA JO CAMPBELL, BILL CROSS, BRIAN LEE FOSTER, BEA
| ASSEMBLY 72
DAUCHER, LYNN NANJUNDAPPA, GANGADHARAPRA ZAMARRA, JOHN WM.
ASSEMBLY 73
BATES, PATRICIA 'PAT' FISHER, PAUL KING, PAUL H. WILBERG, ROBERT D.
| ASSEMBLY 74
BOURDETTE, BARBARA HERRERA, JOHN HOHMAN, TOM WYLAND, MARK B.
ASSEMBLY 75
PIETILA, GARY W. WALTERS, JUDITH K. ZETTEL, CHARLENE
| ASSEMBLY 76
KEHOE, CHRISTINE NASH-HOFF, MICHELE OAKEY, DAVID T.
ASSEMBLY 77
KEEGAN, TODD LA SUER, JAY METTI, MICHAEL S.
| ASSEMBLY 78
STEEL, JOHN TRIGLIA, DENNIS WAYNE, HOWARD WINGFIELD, RAYMOND C.
ASSEMBLY 79
CARDULLA, RICHARD J. PARUNGAO, JON VARGAS, JUAN C.
| ASSEMBLY 80
ACUNA JR., JOEY V. KELLEY, DAVID G. WEBER, SUSAN MARIE